Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/BillboardProjectile.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/BillboardProjectile.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/BillboardProjectile.h	(revision 11054)
@@ -61,5 +61,5 @@
             virtual void setMaterial(const std::string& material);
             virtual const std::string& getMaterial();
-            virtual void changedVisibility();
+            virtual void changedVisibility() override;
 
         private:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBomb.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBomb.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBomb.h	(revision 11054)
@@ -41,7 +41,7 @@
             GravityBomb(Context* context);
             virtual ~GravityBomb();
-            virtual void tick(float dt);
+            virtual void tick(float dt) override;
 
-            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint);
+            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint) override;
             void detonate();
         private:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBombField.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBombField.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBombField.cc	(revision 11054)
@@ -125,18 +125,18 @@
 
             //Check if any pawn is inside the shockwave and hit it with dammage proportional to the distance between explosion centre and pawn. Make sure, the same pawn is damaged only once.
-            for (ObjectList<Pawn>::iterator it = ObjectList<Pawn>::begin(); it != ObjectList<Pawn>::end(); ++it)
+            for (Pawn* pawn : ObjectList<Pawn>())
             {
-                Vector3 distanceVector = it->getWorldPosition()-this->getWorldPosition();
+                Vector3 distanceVector = pawn->getWorldPosition()-this->getWorldPosition();
                  //orxout(debug_output) << "Found Pawn:" << it->getWorldPosition() << endl;
                 if(distanceVector.length()< forceSphereRadius_)
                 {
                     //orxout(debug_output) << "Force sphere radius is: " << forceSphereRadius_ << " Distance to Pawn is: " << distanceVector.length();
-                    if (std::find(victimsAlreadyDamaged_.begin(),victimsAlreadyDamaged_.end(),*it) == victimsAlreadyDamaged_.end())
+                    if (std::find(victimsAlreadyDamaged_.begin(),victimsAlreadyDamaged_.end(),pawn) == victimsAlreadyDamaged_.end())
                     {
                         //orxout(debug_output) << "Found Pawn to damage: " << it->getWorldPosition() << endl;
                         float damage = FORCE_FIELD_EXPLOSION_DAMMAGE*(1-distanceVector.length()/EXPLOSION_RADIUS);
                         //orxout(debug_output) << "Damage: " << damage << endl;
-                        it->hit(shooter_, it->getWorldPosition(), NULL, damage, 0,0);
-                        victimsAlreadyDamaged_.push_back(*it);
+                        pawn->hit(shooter_, pawn->getWorldPosition(), nullptr, damage, 0,0);
+                        victimsAlreadyDamaged_.push_back(pawn);
                     }
                 }
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBombField.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBombField.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/GravityBombField.h	(revision 11054)
@@ -39,5 +39,5 @@
     GravityBombField(Context* context);
     virtual ~GravityBombField();
-    virtual void tick(float dt);
+    virtual void tick(float dt) override;
     virtual void destroy();
 
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/IceGunProjectile.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/IceGunProjectile.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/IceGunProjectile.h	(revision 11054)
@@ -62,5 +62,5 @@
 
         protected:
-            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint);
+            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint) override;
             static const float particleDestructionDelay_;
         private:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/LightningGunProjectile.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/LightningGunProjectile.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/LightningGunProjectile.h	(revision 11054)
@@ -58,5 +58,5 @@
             virtual ~LightningGunProjectile() {}
 
-            virtual void setMaterial(const std::string& material);
+            virtual void setMaterial(const std::string& material) override;
 
         private:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/MineProjectile.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/MineProjectile.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/MineProjectile.cc	(revision 11054)
@@ -217,5 +217,5 @@
             {
                 // Damage all pawns within the damage radius
-                for (ObjectList<Pawn>::iterator it = ObjectList<Pawn>::begin(); it != ObjectList<Pawn>::end(); ++it)
+                for (ObjectList<Pawn>::iterator it = ObjectList<Pawn>().begin(); it; ++it)
                 {
                     Vector3 distanceVector = it->getWorldPosition()-this->getWorldPosition();
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/ParticleProjectile.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/ParticleProjectile.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/ParticleProjectile.cc	(revision 11054)
@@ -58,5 +58,5 @@
         }
         else
-            this->particles_ = 0;
+            this->particles_ = nullptr;
     }
 
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/ParticleProjectile.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/ParticleProjectile.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/ParticleProjectile.h	(revision 11054)
@@ -53,5 +53,5 @@
             ParticleProjectile(Context* context);
             virtual ~ParticleProjectile();
-            virtual void changedVisibility();
+            virtual void changedVisibility() override;
 
         private:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/Projectile.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/Projectile.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/Projectile.cc	(revision 11054)
@@ -94,5 +94,5 @@
     void Projectile::setCollisionShapeRadius(float radius)
     {
-        if (collisionShape_ != NULL && radius > 0)
+        if (collisionShape_ != nullptr && radius > 0)
         {
             collisionShape_->setRadius(radius);
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/Projectile.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/Projectile.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/Projectile.h	(revision 11054)
@@ -64,6 +64,6 @@
             void setConfigValues();
 
-            virtual void tick(float dt);
-            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint);
+            virtual void tick(float dt) override;
+            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint) override;
 
         protected:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/Rocket.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/Rocket.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/Rocket.cc	(revision 11054)
@@ -117,6 +117,6 @@
         else
         {
-            this->defSndWpnEngine_ = 0;
-            this->defSndWpnLaunch_ = 0;
+            this->defSndWpnEngine_ = nullptr;
+            this->defSndWpnLaunch_ = nullptr;
         }
 
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/Rocket.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/Rocket.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/Rocket.h	(revision 11054)
@@ -62,17 +62,17 @@
             virtual ~Rocket();
 
-            virtual void tick(float dt); //!< Defines which actions the Rocket has to take in each tick.
+            virtual void tick(float dt) override; //!< Defines which actions the Rocket has to take in each tick.
 
-            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint);
-            virtual void destroyObject(void);
+            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint) override;
+            virtual void destroyObject(void) override;
             void destructionEffect();
 
-            virtual void moveFrontBack(const Vector2& value) {}
-            virtual void moveRightLeft(const Vector2& value) {}
-            virtual void moveUpDown(const Vector2& value) {}
+            virtual void moveFrontBack(const Vector2& value) override {}
+            virtual void moveRightLeft(const Vector2& value) override {}
+            virtual void moveUpDown(const Vector2& value) override {}
 
-            virtual void rotateYaw(const Vector2& value);
-            virtual void rotatePitch(const Vector2& value);
-            virtual void rotateRoll(const Vector2& value);
+            virtual void rotateYaw(const Vector2& value) override;
+            virtual void rotatePitch(const Vector2& value) override;
+            virtual void rotateRoll(const Vector2& value) override;
 
             /**
@@ -114,7 +114,7 @@
                 { this->rotateRoll(Vector2(value, 0)); }
 
-            virtual void setShooter(Pawn* shooter);
+            virtual void setShooter(Pawn* shooter) override;
 
-            virtual void fired(unsigned int firemode);
+            virtual void fired(unsigned int firemode) override;
 
             /**
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/RocketOld.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/RocketOld.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/RocketOld.cc	(revision 11054)
@@ -117,6 +117,6 @@
         else
         {
-            this->defSndWpnEngine_ = 0;
-            this->defSndWpnLaunch_ = 0;
+            this->defSndWpnEngine_ = nullptr;
+            this->defSndWpnLaunch_ = nullptr;
         }
 
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/RocketOld.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/RocketOld.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/RocketOld.h	(revision 11054)
@@ -62,17 +62,17 @@
             virtual ~RocketOld();
 
-            virtual void tick(float dt); //!< Defines which actions the RocketOld has to take in each tick.
+            virtual void tick(float dt) override; //!< Defines which actions the RocketOld has to take in each tick.
 
-            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint);
-            virtual void destroyObject(void);
+            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint) override;
+            virtual void destroyObject(void) override;
             void destructionEffect();
 
-            virtual void moveFrontBack(const Vector2& value) {}
-            virtual void moveRightLeft(const Vector2& value) {}
-            virtual void moveUpDown(const Vector2& value) {}
+            virtual void moveFrontBack(const Vector2& value) override {}
+            virtual void moveRightLeft(const Vector2& value) override {}
+            virtual void moveUpDown(const Vector2& value) override {}
 
-            virtual void rotateYaw(const Vector2& value);
-            virtual void rotatePitch(const Vector2& value);
-            virtual void rotateRoll(const Vector2& value);
+            virtual void rotateYaw(const Vector2& value) override;
+            virtual void rotatePitch(const Vector2& value) override;
+            virtual void rotateRoll(const Vector2& value) override;
 
             /**
@@ -114,7 +114,7 @@
                 { this->rotateRoll(Vector2(value, 0)); }
 
-            virtual void setShooter(Pawn* shooter);
+            virtual void setShooter(Pawn* shooter) override;
 
-            virtual void fired(unsigned int firemode);
+            virtual void fired(unsigned int firemode) override;
 
         private:
Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/SimpleRocket.h
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/SimpleRocket.h	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/SimpleRocket.h	(revision 11054)
@@ -62,17 +62,17 @@
             SimpleRocket(Context* context);
             virtual ~SimpleRocket();
-            virtual void tick(float dt);
+            virtual void tick(float dt) override;
 
-            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint);
+            virtual bool collidesAgainst(WorldEntity* otherObject, const btCollisionShape* cs, btManifoldPoint& contactPoint) override;
 
             void disableFire(); //!< Method to disable the fire and stop all acceleration
 
-            virtual void moveFrontBack(const Vector2& value){}
-            virtual void moveRightLeft(const Vector2& value){}
-            virtual void moveUpDown(const Vector2& value){}
+            virtual void moveFrontBack(const Vector2& value) override{}
+            virtual void moveRightLeft(const Vector2& value) override{}
+            virtual void moveUpDown(const Vector2& value) override{}
 
-            virtual void rotateYaw(const Vector2& value);
-            virtual void rotatePitch(const Vector2& value);
-            virtual void rotateRoll(const Vector2& value);
+            virtual void rotateYaw(const Vector2& value) override;
+            virtual void rotatePitch(const Vector2& value) override;
+            virtual void rotateRoll(const Vector2& value) override;
             void setDestroy();
 
@@ -115,5 +115,5 @@
                 { this->rotateRoll(Vector2(value, 0)); }
 
-            virtual void setShooter(Pawn* shooter);
+            virtual void setShooter(Pawn* shooter) override;
 
             inline bool hasFuel() const

Index: code/branches/cpp11_v3/src/modules/weapons/projectiles/BasicProjectile.cc
===================================================================
--- code/branches/cpp11_v3/src/modules/weapons/projectiles/BasicProjectile.cc	(revision 11053)
+++ code/branches/cpp11_v3/src/modules/weapons/projectiles/BasicProjectile.cc	(revision 11054)
@@ -88,5 +88,5 @@
                                     // The projectile is destroyed by its tick()-function (in the following tick).
 
-            Pawn* victim = orxonox_cast<Pawn*>(otherObject); // If otherObject isn't a Pawn, then victim is NULL
+            Pawn* victim = orxonox_cast<Pawn*>(otherObject); // If otherObject isn't a Pawn, then victim is nullptr
 
             WorldEntity* entity = orxonox_cast<WorldEntity*>(this);
@@ -146,8 +146,8 @@
     bool BasicProjectile::isObjectRelatedToShooter(WorldEntity* otherObject)
     {
-        for (WorldEntity* shooter = this->getShooter(); shooter != NULL; shooter = shooter->getParent())
+        for (WorldEntity* shooter = this->getShooter(); shooter != nullptr; shooter = shooter->getParent())
             if (otherObject == shooter)
                 return true;
-        for (WorldEntity* object = otherObject; object != NULL; object = object->getParent())
+        for (WorldEntity* object = otherObject; object != nullptr; object = object->getParent())
             if (otherObject == this->getShooter())
                 return true;